summaryrefslogtreecommitdiffstats
path: root/korn/boxcontaineritem.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/boxcontaineritem.h')
-rw-r--r--korn/boxcontaineritem.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/korn/boxcontaineritem.h b/korn/boxcontaineritem.h
index 5393852a..bd03801a 100644
--- a/korn/boxcontaineritem.h
+++ b/korn/boxcontaineritem.h
@@ -51,11 +51,11 @@ public:
* This constructor implements the default arguments for any TQObject.
* Note that is does not give a name to DCOPObject; that name
* is set in the readConfig-function.
* @param tqparent The tqparent of this object, See Object::TQObject
* @param name The name of this object, See TQObject::TQObject
* @see BoxContainerItem::readConfig
*/
- BoxContainerItem( TQObject * tqparent = 0, const char * name = 0 );
+ BoxContainerItem( TQObject * parent = 0, const char * name = 0 );
/**
* The default destructor. This only removes _command-pointer.
@@ -124,13 +124,13 @@ protected:
/**
* This displays the passive popup.
*
* @param tqparent The Winget of the visual widget
* @param list List with the first (five) subjects
* @param total The total numbers of unread mail
* @param accountName The name of the account it belongs to
* @param date Should the date be displayed?
*/
- void showPassivePopup( TQWidget* tqparent, TQPtrList< KornMailSubject >* list, int total, const TQString& accountName, bool date );
+ void showPassivePopup( TQWidget* parent, TQPtrList< KornMailSubject >* list, int total, const TQString& accountName, bool date );
//this functions should be reimplemented
/**
@@ -51,11 +51,11 @@ public:
* Note that is does not give a name to DCOPObject; that name
* is set in the readConfig-function.
- * @param tqparent The tqparent of this object, See Object::TQObject
+ * @param parent The parent of this object, See Object::TQObject
* @param name The name of this object, See TQObject::TQObject
* @see BoxContainerItem::readConfig
@@ -124,13 +124,13 @@ protected:
* This displays the passive popup.
*
- * @param tqparent The Winget of the visual widget
+ * @param parent The Winget of the visual widget
* @param list List with the first (five) subjects
* @param total The total numbers of unread mail